@@ -14,16 +14,16 @@ from .carbon import *
 from .errors import CarbonError
 from .opts import *
 
-__version__ = '1.0.2'
+VersionInfo = namedtuple('VersionInfo', 'major minor micro releaselevel serial')
+
+version_info = VersionInfo(major=1, minor=0, micro=3, releaselevel='final', serial=0)
+
+__version__ = f'{version_info.major}.{version_info.minor}.{version_info.micro}'
 __title__ = 'py-carbon'
 __license__ = 'MIT'
 __author__ = 'wulf'
-__email__ = 'support@statch.tech'
+__email__ = 'paul@przybyszewski.me'
 __uri__ = "https://github.com/statch/py-carbon"
-__copyright__ = 'Copyright 2021-2021 %s' % __author__
+__copyright__ = 'Copyright 2021-2022 %s' % __author__
 
 __path__ = __import__('pkgutil').extend_path(__path__, __name__)
-
-VersionInfo = namedtuple('VersionInfo', 'major minor micro releaselevel serial')
-
-version_info = VersionInfo(major=1, minor=0, micro=0, releaselevel='final', serial=0)
